//----------------------------------------------------//
// Wide Studio Application C++ Source File            //
//            created by Wide Studio source generator //
//----------------------------------------------------//
#include <WScom.h>
#include <WSDappDev.h>

//--- OBJECT includes ---//
#include <WSCmainWindow.h>
#include <WSCvkslabel.h>
#include <WSCvtimer.h>
#include <WSCvscrBar.h>
#include <WSCcomboBox.h>
#include <WSCvbtn.h>
#include <WSCvlabel.h>
#include <WSCmenuArea.h>
#include <WSCpulldownMenu.h>
#include <WSCdialog.h>
#include <WSCvifield.h>
#include <WSCvtoggle.h>
#include <WSCvslider.h>

//--- OBJECT instance variable ---//
WSCmainWindow* MainWin;
WSCvkslabel* Maivksl_HeadLine;
WSCvtimer* Maivtim_MainTimer;
WSCvtimer* Maivtim_BeginTimer;
WSCvscrBar* Maivscr_ScrollBar;
WSCcomboBox* Maicomb_NameList;
WSCvbtn* Maivbtn_StopBtn;
WSCvbtn* Maivbtn_NextUrlBtn;
WSCvbtn* Maivbtn_PrevUrlBtn;
WSCvbtn* Maivbtn_NextArtBtn;
WSCvbtn* Maivbtn_PrevArtBtn;
WSCvlabel* Maivlab_Art;
WSCvlabel* Maivlab_Thr;
WSCvbtn* Maivbtn_NextThrBtn;
WSCvbtn* Maivbtn_PrevThrBtn;
WSCvlabel* Maivlab_Site;
WSCvbtn* Maivbtn_BarBtn;
WSCvtimer* Maivtim_UpdateTimer;
WSCmenuArea* Maimenu_MainMenu;
WSCpulldownMenu* Maipull_MainMenuFile;
WSCpulldownMenu* Maipull_MainMenuOpt;
WSCdialog* Cnfdial_ConfigUrl;
WSCvbtn* Cnfvbtn_NewBtn;
WSCvbtn* Cnfvbtn_UpdateBtn;
WSCvifield* Cnfvifi_Name;
WSCvifield* Cnfvifi_Url;
WSCvlabel* Cnfvlab_Name;
WSCvlabel* Cnfvlab_Url;
WSCvtoggle* Cnfvtog_Download;
WSCvbtn* Cnfvbtn_DeleteBtn;
WSCcomboBox* Cnfcomb_NameList;
WSCcomboBox* Cnfcomb_Encoding;
WSCvlabel* Cnfvlab_Encoding;
WSCvlabel* Cnfvlab_OrderTitle;
WSCvlabel* Cnfvlab_Order;
WSCvbtn* Cnfvbtn_UpBtn;
WSCvbtn* Cnfvbtn_DownBtn;
WSCvbtn* Cnfvbtn_TopBtn;
WSCvbtn* Cnfvbtn_BottomBtn;
WSCvlabel* Cnfvlab_SkipArt;
WSCvslider* Cnfvsli_SkipArt;
WSCvifield* Cnfvifi_SkipArt;
WSCvtimer* Maivtim_ReloadTimer;
WSCdialog* Misdial_ConfigMisc;
WSCvlabel* Misvlab_Chars;
WSCvifield* Misvifi_Chars;
WSCvslider* Misvsli_Chars;
WSCvlabel* Misvlab_Speed;
WSCvifield* Misvifi_Speed;
WSCvslider* Misvsli_Speed;
WSCvlabel* Misvlab_Wait;
WSCvifield* Misvifi_Wait;
WSCvslider* Misvsli_Wait;
WSCcomboBox* Miscomb_Language;
WSCvlabel* Misvlab_Language;

//--- OBJECT src ---//

WSCbase* _create_win_MainWin(){


  MainWin = new  WSCmainWindow(NULL,"MainWin");
      MainWin->initialize();
  MainWin->setPropertyV(WSNname,"MainWin");
  MainWin->setPropertyV(WSNtitleString,"News Head Line");
  MainWin->setPropertyV(WSNx,(short)100);
  MainWin->setPropertyV(WSNy,(short)100);
  MainWin->setPropertyV(WSNwidth,(unsigned short)640);
  MainWin->setPropertyV(WSNheight,(unsigned short)240);
  MainWin->setPropertyV(WSNbackColor,"#dcdcdc");
  MainWin->setPropertyV(WSNtopShadowColor,"#ffffff");
  MainWin->setPropertyV(WSNbottomShadowColor,"#b4b4b4");
  MainWin->setPropertyV(WSNvis,(WSCbool)1);
    WSCprocedure* op_MainWin_5 = new WSCprocedure("MainWinInit",0);
    extern void MainWinInit(WSCbase*);
    op_MainWin_5->setFunction(MainWinInit,"MainWinInit");
    MainWin->addProcedure(op_MainWin_5);
    WSCprocedure* op_MainWin_6 = new WSCprocedure("MainWinFixSize",11);
    extern void MainWinFixSize(WSCbase*);
    op_MainWin_6->setFunction(MainWinFixSize,"MainWinFixSize");
    MainWin->addProcedure(op_MainWin_6);
    WSCprocedure* op_MainWin_7 = new WSCprocedure("MainWinExit",32);
    extern void MainWinExit(WSCbase*);
    op_MainWin_7->setFunction(MainWinExit,"MainWinExit");
    MainWin->addProcedure(op_MainWin_7);

  Maivksl_HeadLine = new  WSCvkslabel(MainWin,"Maivksl_HeadLine");
      Maivksl_HeadLine->initialize();
  Maivksl_HeadLine->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maivksl_HeadLine->setPropertyV(WSNmaxLength,(unsigned short)512);
  Maivksl_HeadLine->setPropertyV(WSNname,"Maivksl_HeadLine");
  Maivksl_HeadLine->setPropertyV(WSNvis,(WSCbool)1);
  Maivksl_HeadLine->setPropertyV(WSNx,(short)20);
  Maivksl_HeadLine->setPropertyV(WSNy,(short)100);
  Maivksl_HeadLine->setPropertyV(WSNwidth,(unsigned short)600);
  Maivksl_HeadLine->setPropertyV(WSNanchorTop,(unsigned short)100);
  Maivksl_HeadLine->setPropertyV(WSNanchorBottom,(unsigned short)20);
  Maivksl_HeadLine->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Maivksl_HeadLine->setPropertyV(WSNanchorRight,(unsigned short)20);
  Maivksl_HeadLine->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maivksl_HeadLine->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
  Maivksl_HeadLine->setPropertyV(WSNanchorRightFlag,(WSCbool)1);

  Maivtim_MainTimer = new  WSCvtimer(MainWin,"Maivtim_MainTimer");
      Maivtim_MainTimer->initialize();
  Maivtim_MainTimer->setPropertyV(WSNinterval,(unsigned long)400);
  Maivtim_MainTimer->setPropertyV(WSNrunning,(WSCbool)1);
  Maivtim_MainTimer->setPropertyV(WSNname,"Maivtim_MainTimer");
  Maivtim_MainTimer->setPropertyV(WSNvis,(WSCbool)1);
  Maivtim_MainTimer->setPropertyV(WSNx,(short)20);
  Maivtim_MainTimer->setPropertyV(WSNy,(short)150);
  Maivtim_MainTimer->setPropertyV(WSNwidth,(unsigned short)60);
    WSCprocedure* op_Maivtim_MainTimer_5 = new WSCprocedure("MainTimerUpdate",2);
    extern void MainTimerUpdate(WSCbase*);
    op_Maivtim_MainTimer_5->setFunction(MainTimerUpdate,"MainTimerUpdate");
    Maivtim_MainTimer->addProcedure(op_Maivtim_MainTimer_5);

  Maivtim_BeginTimer = new  WSCvtimer(MainWin,"Maivtim_BeginTimer");
      Maivtim_BeginTimer->initialize();
  Maivtim_BeginTimer->setPropertyV(WSNinterval,(unsigned long)4000);
  Maivtim_BeginTimer->setPropertyV(WSNcont,(WSCbool)0);
  Maivtim_BeginTimer->setPropertyV(WSNname,"Maivtim_BeginTimer");
  Maivtim_BeginTimer->setPropertyV(WSNvis,(WSCbool)1);
  Maivtim_BeginTimer->setPropertyV(WSNx,(short)20);
  Maivtim_BeginTimer->setPropertyV(WSNy,(short)180);
  Maivtim_BeginTimer->setPropertyV(WSNwidth,(unsigned short)60);
    WSCprocedure* op_Maivtim_BeginTimer_5 = new WSCprocedure("BeginTimerUpdate",2);
    extern void BeginTimerUpdate(WSCbase*);
    op_Maivtim_BeginTimer_5->setFunction(BeginTimerUpdate,"BeginTimerUpdate");
    Maivtim_BeginTimer->addProcedure(op_Maivtim_BeginTimer_5);

  Maivscr_ScrollBar = new  WSCvscrBar(MainWin,"Maivscr_ScrollBar");
      Maivscr_ScrollBar->initialize();
  Maivscr_ScrollBar->setPropertyV(WSNvalue,(unsigned long)260);
  Maivscr_ScrollBar->setPropertyV(WSNname,"Maivscr_ScrollBar");
  Maivscr_ScrollBar->setPropertyV(WSNvis,(WSCbool)1);
  Maivscr_ScrollBar->setPropertyV(WSNx,(short)20);
  Maivscr_ScrollBar->setPropertyV(WSNy,(short)130);
  Maivscr_ScrollBar->setPropertyV(WSNwidth,(unsigned short)600);
  Maivscr_ScrollBar->setPropertyV(WSNheight,(unsigned short)20);
  Maivscr_ScrollBar->setPropertyV(WSNanchorTop,(unsigned short)130);
  Maivscr_ScrollBar->setPropertyV(WSNanchorBottom,(unsigned short)20);
  Maivscr_ScrollBar->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Maivscr_ScrollBar->setPropertyV(WSNanchorRight,(unsigned short)20);
  Maivscr_ScrollBar->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maivscr_ScrollBar->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
  Maivscr_ScrollBar->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Maivscr_ScrollBar_5 = new WSCprocedure("ScrollBarChange",3);
    extern void ScrollBarChange(WSCbase*);
    op_Maivscr_ScrollBar_5->setFunction(ScrollBarChange,"ScrollBarChange");
    Maivscr_ScrollBar->addProcedure(op_Maivscr_ScrollBar_5);
    WSCprocedure* op_Maivscr_ScrollBar_6 = new WSCprocedure("ScrollBarBegin",38);
    extern void ScrollBarBegin(WSCbase*);
    op_Maivscr_ScrollBar_6->setFunction(ScrollBarBegin,"ScrollBarBegin");
    Maivscr_ScrollBar->addProcedure(op_Maivscr_ScrollBar_6);
    WSCprocedure* op_Maivscr_ScrollBar_7 = new WSCprocedure("ScrollBarEnd",39);
    extern void ScrollBarEnd(WSCbase*);
    op_Maivscr_ScrollBar_7->setFunction(ScrollBarEnd,"ScrollBarEnd");
    Maivscr_ScrollBar->addProcedure(op_Maivscr_ScrollBar_7);
    WSCprocedure* op_Maivscr_ScrollBar_8 = new WSCprocedure("ScrollBarInc",40);
    extern void ScrollBarInc(WSCbase*);
    op_Maivscr_ScrollBar_8->setFunction(ScrollBarInc,"ScrollBarInc");
    Maivscr_ScrollBar->addProcedure(op_Maivscr_ScrollBar_8);
    WSCprocedure* op_Maivscr_ScrollBar_9 = new WSCprocedure("ScrollBarPageInc",42);
    extern void ScrollBarPageInc(WSCbase*);
    op_Maivscr_ScrollBar_9->setFunction(ScrollBarPageInc,"ScrollBarPageInc");
    Maivscr_ScrollBar->addProcedure(op_Maivscr_ScrollBar_9);
    WSCprocedure* op_Maivscr_ScrollBar_10 = new WSCprocedure("ScrollBarDec",41);
    extern void ScrollBarDec(WSCbase*);
    op_Maivscr_ScrollBar_10->setFunction(ScrollBarDec,"ScrollBarDec");
    Maivscr_ScrollBar->addProcedure(op_Maivscr_ScrollBar_10);
    WSCprocedure* op_Maivscr_ScrollBar_11 = new WSCprocedure("ScrollBarPageDec",43);
    extern void ScrollBarPageDec(WSCbase*);
    op_Maivscr_ScrollBar_11->setFunction(ScrollBarPageDec,"ScrollBarPageDec");
    Maivscr_ScrollBar->addProcedure(op_Maivscr_ScrollBar_11);

  Maicomb_NameList = new  WSCcomboBox(MainWin,"Maicomb_NameList");
      Maicomb_NameList->initialize();
  Maicomb_NameList->setPropertyV(WSNmenuItems,"");
  Maicomb_NameList->setPropertyV(WSNbackBlinkColor,"DEF13");
  Maicomb_NameList->setPropertyV(WSNworkBackColor,"DEF11");
  Maicomb_NameList->setPropertyV(WSNusePixmap,(unsigned char)1);
  Maicomb_NameList->setPropertyV(WSNalignmentH,(unsigned char)0);
  Maicomb_NameList->setPropertyV(WSNmaxLength,(unsigned short)512);
  Maicomb_NameList->setPropertyV(WSNfont,(unsigned char)1);
  Maicomb_NameList->setPropertyV(WSNname,"Maicomb_NameList");
  Maicomb_NameList->setPropertyV(WSNx,(short)20);
  Maicomb_NameList->setPropertyV(WSNy,(short)50);
  Maicomb_NameList->setPropertyV(WSNwidth,(unsigned short)600);
  Maicomb_NameList->setPropertyV(WSNvis,(WSCbool)1);
  Maicomb_NameList->setPropertyV(WSNanchorTop,(unsigned short)50);
  Maicomb_NameList->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Maicomb_NameList->setPropertyV(WSNanchorRight,(unsigned short)20);
  Maicomb_NameList->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maicomb_NameList->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
  Maicomb_NameList->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Maicomb_NameList_5 = new WSCprocedure("NameListSelect",2);
    extern void NameListSelect(WSCbase*);
    op_Maicomb_NameList_5->setFunction(NameListSelect,"NameListSelect");
    Maicomb_NameList->addProcedure(op_Maicomb_NameList_5);

  Maivbtn_StopBtn = new  WSCvbtn(MainWin,"Maivbtn_StopBtn");
      Maivbtn_StopBtn->initialize();
  Maivbtn_StopBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maivbtn_StopBtn->setPropertyV(WSNlabelString,"||");
  Maivbtn_StopBtn->setPropertyV(WSNname,"Maivbtn_StopBtn");
  Maivbtn_StopBtn->setPropertyV(WSNvis,(WSCbool)1);
  Maivbtn_StopBtn->setPropertyV(WSNx,(short)240);
  Maivbtn_StopBtn->setPropertyV(WSNy,(short)150);
  Maivbtn_StopBtn->setPropertyV(WSNwidth,(unsigned short)50);
  Maivbtn_StopBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
  Maivbtn_StopBtn->setPropertyV(WSNanchorRight,(unsigned short)350);
  Maivbtn_StopBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maivbtn_StopBtn->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Maivbtn_StopBtn_5 = new WSCprocedure("StopBtnPush",2);
    extern void StopBtnPush(WSCbase*);
    op_Maivbtn_StopBtn_5->setFunction(StopBtnPush,"StopBtnPush");
    Maivbtn_StopBtn->addProcedure(op_Maivbtn_StopBtn_5);

  Maivbtn_NextUrlBtn = new  WSCvbtn(MainWin,"Maivbtn_NextUrlBtn");
      Maivbtn_NextUrlBtn->initialize();
  Maivbtn_NextUrlBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maivbtn_NextUrlBtn->setPropertyV(WSNlabelString,"NEXT");
  Maivbtn_NextUrlBtn->setPropertyV(WSNname,"Maivbtn_NextUrlBtn");
  Maivbtn_NextUrlBtn->setPropertyV(WSNvis,(WSCbool)1);
  Maivbtn_NextUrlBtn->setPropertyV(WSNx,(short)350);
  Maivbtn_NextUrlBtn->setPropertyV(WSNy,(short)150);
  Maivbtn_NextUrlBtn->setPropertyV(WSNwidth,(unsigned short)50);
  Maivbtn_NextUrlBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
  Maivbtn_NextUrlBtn->setPropertyV(WSNanchorRight,(unsigned short)240);
  Maivbtn_NextUrlBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maivbtn_NextUrlBtn->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Maivbtn_NextUrlBtn_5 = new WSCprocedure("NextUrlBtnPush",2);
    extern void NextUrlBtnPush(WSCbase*);
    op_Maivbtn_NextUrlBtn_5->setFunction(NextUrlBtnPush,"NextUrlBtnPush");
    Maivbtn_NextUrlBtn->addProcedure(op_Maivbtn_NextUrlBtn_5);

  Maivbtn_PrevUrlBtn = new  WSCvbtn(MainWin,"Maivbtn_PrevUrlBtn");
      Maivbtn_PrevUrlBtn->initialize();
  Maivbtn_PrevUrlBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maivbtn_PrevUrlBtn->setPropertyV(WSNlabelString,"PREV");
  Maivbtn_PrevUrlBtn->setPropertyV(WSNname,"Maivbtn_PrevUrlBtn");
  Maivbtn_PrevUrlBtn->setPropertyV(WSNvis,(WSCbool)1);
  Maivbtn_PrevUrlBtn->setPropertyV(WSNx,(short)300);
  Maivbtn_PrevUrlBtn->setPropertyV(WSNy,(short)150);
  Maivbtn_PrevUrlBtn->setPropertyV(WSNwidth,(unsigned short)50);
  Maivbtn_PrevUrlBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
  Maivbtn_PrevUrlBtn->setPropertyV(WSNanchorRight,(unsigned short)290);
  Maivbtn_PrevUrlBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maivbtn_PrevUrlBtn->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Maivbtn_PrevUrlBtn_5 = new WSCprocedure("PrevUrlBtnPush",2);
    extern void PrevUrlBtnPush(WSCbase*);
    op_Maivbtn_PrevUrlBtn_5->setFunction(PrevUrlBtnPush,"PrevUrlBtnPush");
    Maivbtn_PrevUrlBtn->addProcedure(op_Maivbtn_PrevUrlBtn_5);

  Maivbtn_NextArtBtn = new  WSCvbtn(MainWin,"Maivbtn_NextArtBtn");
      Maivbtn_NextArtBtn->initialize();
  Maivbtn_NextArtBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maivbtn_NextArtBtn->setPropertyV(WSNlabelString,">|");
  Maivbtn_NextArtBtn->setPropertyV(WSNname,"Maivbtn_NextArtBtn");
  Maivbtn_NextArtBtn->setPropertyV(WSNvis,(WSCbool)1);
  Maivbtn_NextArtBtn->setPropertyV(WSNx,(short)570);
  Maivbtn_NextArtBtn->setPropertyV(WSNy,(short)150);
  Maivbtn_NextArtBtn->setPropertyV(WSNwidth,(unsigned short)50);
  Maivbtn_NextArtBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
  Maivbtn_NextArtBtn->setPropertyV(WSNanchorRight,(unsigned short)20);
  Maivbtn_NextArtBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maivbtn_NextArtBtn->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Maivbtn_NextArtBtn_5 = new WSCprocedure("NextArtPush",2);
    extern void NextArtPush(WSCbase*);
    op_Maivbtn_NextArtBtn_5->setFunction(NextArtPush,"NextArtPush");
    Maivbtn_NextArtBtn->addProcedure(op_Maivbtn_NextArtBtn_5);

  Maivbtn_PrevArtBtn = new  WSCvbtn(MainWin,"Maivbtn_PrevArtBtn");
      Maivbtn_PrevArtBtn->initialize();
  Maivbtn_PrevArtBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maivbtn_PrevArtBtn->setPropertyV(WSNlabelString,"|<");
  Maivbtn_PrevArtBtn->setPropertyV(WSNname,"Maivbtn_PrevArtBtn");
  Maivbtn_PrevArtBtn->setPropertyV(WSNvis,(WSCbool)1);
  Maivbtn_PrevArtBtn->setPropertyV(WSNx,(short)520);
  Maivbtn_PrevArtBtn->setPropertyV(WSNy,(short)150);
  Maivbtn_PrevArtBtn->setPropertyV(WSNwidth,(unsigned short)50);
  Maivbtn_PrevArtBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
  Maivbtn_PrevArtBtn->setPropertyV(WSNanchorRight,(unsigned short)70);
  Maivbtn_PrevArtBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maivbtn_PrevArtBtn->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Maivbtn_PrevArtBtn_5 = new WSCprocedure("PrevArtPush",2);
    extern void PrevArtPush(WSCbase*);
    op_Maivbtn_PrevArtBtn_5->setFunction(PrevArtPush,"PrevArtPush");
    Maivbtn_PrevArtBtn->addProcedure(op_Maivbtn_PrevArtBtn_5);

  Maivlab_Art = new  WSCvlabel(MainWin,"Maivlab_Art");
      Maivlab_Art->initialize();
  Maivlab_Art->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maivlab_Art->setPropertyV(WSNlabelString,"ARTICLE");
  Maivlab_Art->setPropertyV(WSNname,"Maivlab_Art");
  Maivlab_Art->setPropertyV(WSNvis,(WSCbool)1);
  Maivlab_Art->setPropertyV(WSNx,(short)520);
  Maivlab_Art->setPropertyV(WSNy,(short)180);
  Maivlab_Art->setPropertyV(WSNanchorTop,(unsigned short)180);
  Maivlab_Art->setPropertyV(WSNanchorRight,(unsigned short)20);
  Maivlab_Art->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maivlab_Art->setPropertyV(WSNanchorRightFlag,(WSCbool)1);

  Maivlab_Thr = new  WSCvlabel(MainWin,"Maivlab_Thr");
      Maivlab_Thr->initialize();
  Maivlab_Thr->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maivlab_Thr->setPropertyV(WSNlabelString,"THREAD");
  Maivlab_Thr->setPropertyV(WSNname,"Maivlab_Thr");
  Maivlab_Thr->setPropertyV(WSNvis,(WSCbool)1);
  Maivlab_Thr->setPropertyV(WSNx,(short)410);
  Maivlab_Thr->setPropertyV(WSNy,(short)180);
  Maivlab_Thr->setPropertyV(WSNanchorTop,(unsigned short)180);
  Maivlab_Thr->setPropertyV(WSNanchorRight,(unsigned short)130);
  Maivlab_Thr->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maivlab_Thr->setPropertyV(WSNanchorRightFlag,(WSCbool)1);

  Maivbtn_NextThrBtn = new  WSCvbtn(MainWin,"Maivbtn_NextThrBtn");
      Maivbtn_NextThrBtn->initialize();
  Maivbtn_NextThrBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maivbtn_NextThrBtn->setPropertyV(WSNlabelString,">>|");
  Maivbtn_NextThrBtn->setPropertyV(WSNname,"Maivbtn_NextThrBtn");
  Maivbtn_NextThrBtn->setPropertyV(WSNvis,(WSCbool)1);
  Maivbtn_NextThrBtn->setPropertyV(WSNx,(short)460);
  Maivbtn_NextThrBtn->setPropertyV(WSNy,(short)150);
  Maivbtn_NextThrBtn->setPropertyV(WSNwidth,(unsigned short)50);
  Maivbtn_NextThrBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
  Maivbtn_NextThrBtn->setPropertyV(WSNanchorRight,(unsigned short)130);
  Maivbtn_NextThrBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maivbtn_NextThrBtn->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Maivbtn_NextThrBtn_5 = new WSCprocedure("NextThrBtnPush",2);
    extern void NextThrBtnPush(WSCbase*);
    op_Maivbtn_NextThrBtn_5->setFunction(NextThrBtnPush,"NextThrBtnPush");
    Maivbtn_NextThrBtn->addProcedure(op_Maivbtn_NextThrBtn_5);

  Maivbtn_PrevThrBtn = new  WSCvbtn(MainWin,"Maivbtn_PrevThrBtn");
      Maivbtn_PrevThrBtn->initialize();
  Maivbtn_PrevThrBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maivbtn_PrevThrBtn->setPropertyV(WSNlabelString,"|<<");
  Maivbtn_PrevThrBtn->setPropertyV(WSNname,"Maivbtn_PrevThrBtn");
  Maivbtn_PrevThrBtn->setPropertyV(WSNvis,(WSCbool)1);
  Maivbtn_PrevThrBtn->setPropertyV(WSNx,(short)410);
  Maivbtn_PrevThrBtn->setPropertyV(WSNy,(short)150);
  Maivbtn_PrevThrBtn->setPropertyV(WSNwidth,(unsigned short)50);
  Maivbtn_PrevThrBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
  Maivbtn_PrevThrBtn->setPropertyV(WSNanchorRight,(unsigned short)180);
  Maivbtn_PrevThrBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maivbtn_PrevThrBtn->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Maivbtn_PrevThrBtn_5 = new WSCprocedure("PrevThrBtnPush",2);
    extern void PrevThrBtnPush(WSCbase*);
    op_Maivbtn_PrevThrBtn_5->setFunction(PrevThrBtnPush,"PrevThrBtnPush");
    Maivbtn_PrevThrBtn->addProcedure(op_Maivbtn_PrevThrBtn_5);

  Maivlab_Site = new  WSCvlabel(MainWin,"Maivlab_Site");
      Maivlab_Site->initialize();
  Maivlab_Site->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maivlab_Site->setPropertyV(WSNlabelString,"SITE");
  Maivlab_Site->setPropertyV(WSNname,"Maivlab_Site");
  Maivlab_Site->setPropertyV(WSNvis,(WSCbool)1);
  Maivlab_Site->setPropertyV(WSNx,(short)300);
  Maivlab_Site->setPropertyV(WSNy,(short)180);
  Maivlab_Site->setPropertyV(WSNanchorTop,(unsigned short)180);
  Maivlab_Site->setPropertyV(WSNanchorRight,(unsigned short)240);
  Maivlab_Site->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maivlab_Site->setPropertyV(WSNanchorRightFlag,(WSCbool)1);

  Maivbtn_BarBtn = new  WSCvbtn(MainWin,"Maivbtn_BarBtn");
      Maivbtn_BarBtn->initialize();
  Maivbtn_BarBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maivbtn_BarBtn->setPropertyV(WSNlabelString,"BAR");
  Maivbtn_BarBtn->setPropertyV(WSNname,"Maivbtn_BarBtn");
  Maivbtn_BarBtn->setPropertyV(WSNvis,(WSCbool)1);
  Maivbtn_BarBtn->setPropertyV(WSNx,(short)180);
  Maivbtn_BarBtn->setPropertyV(WSNy,(short)150);
  Maivbtn_BarBtn->setPropertyV(WSNwidth,(unsigned short)50);
  Maivbtn_BarBtn->setPropertyV(WSNanchorTop,(unsigned short)150);
  Maivbtn_BarBtn->setPropertyV(WSNanchorRight,(unsigned short)410);
  Maivbtn_BarBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Maivbtn_BarBtn->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Maivbtn_BarBtn_5 = new WSCprocedure("BarBtnPush",2);
    extern void BarBtnPush(WSCbase*);
    op_Maivbtn_BarBtn_5->setFunction(BarBtnPush,"BarBtnPush");
    Maivbtn_BarBtn->addProcedure(op_Maivbtn_BarBtn_5);

  Maivtim_UpdateTimer = new  WSCvtimer(MainWin,"Maivtim_UpdateTimer");
      Maivtim_UpdateTimer->initialize();
  Maivtim_UpdateTimer->setPropertyV(WSNrunning,(WSCbool)1);
  Maivtim_UpdateTimer->setPropertyV(WSNname,"Maivtim_UpdateTimer");
  Maivtim_UpdateTimer->setPropertyV(WSNvis,(WSCbool)1);
  Maivtim_UpdateTimer->setPropertyV(WSNx,(short)80);
  Maivtim_UpdateTimer->setPropertyV(WSNy,(short)150);
  Maivtim_UpdateTimer->setPropertyV(WSNwidth,(unsigned short)60);
    WSCprocedure* op_Maivtim_UpdateTimer_5 = new WSCprocedure("UpdateTimerUpdate",2);
    extern void UpdateTimerUpdate(WSCbase*);
    op_Maivtim_UpdateTimer_5->setFunction(UpdateTimerUpdate,"UpdateTimerUpdate");
    Maivtim_UpdateTimer->addProcedure(op_Maivtim_UpdateTimer_5);

  Maimenu_MainMenu = new  WSCmenuArea(MainWin,"Maimenu_MainMenu");
      Maimenu_MainMenu->initialize();
  Maimenu_MainMenu->setPropertyV(WSNname,"Maimenu_MainMenu");
  Maimenu_MainMenu->setPropertyV(WSNx,(short)0);
  Maimenu_MainMenu->setPropertyV(WSNy,(short)0);
  Maimenu_MainMenu->setPropertyV(WSNwidth,(unsigned short)640);
  Maimenu_MainMenu->setPropertyV(WSNvis,(WSCbool)1);
  Maimenu_MainMenu->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
  Maimenu_MainMenu->setPropertyV(WSNanchorRightFlag,(WSCbool)1);

  Maipull_MainMenuFile = new  WSCpulldownMenu(Maimenu_MainMenu,"Maipull_MainMenuFile");
      Maipull_MainMenuFile->initialize();
  Maipull_MainMenuFile->setPropertyV(WSNmenuItems,"Exit(X):MainMenuExit:X:1");
  Maipull_MainMenuFile->setPropertyV(WSNshortcut,"F");
  Maipull_MainMenuFile->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maipull_MainMenuFile->setPropertyV(WSNlabelString,"File(F)");
  Maipull_MainMenuFile->setPropertyV(WSNname,"Maipull_MainMenuFile");
  Maipull_MainMenuFile->setPropertyV(WSNvis,(WSCbool)1);
  Maipull_MainMenuFile->setPropertyV(WSNheight,(unsigned short)28);
    WSCprocedure* op_Maipull_MainMenuFile_5 = new WSCprocedure("MainMenuExit",-1);
    extern void MainMenuExit(WSCbase*);
    op_Maipull_MainMenuFile_5->setFunction(MainMenuExit,"MainMenuExit");
    Maipull_MainMenuFile->addProcedure(op_Maipull_MainMenuFile_5);

  Maipull_MainMenuOpt = new  WSCpulldownMenu(Maimenu_MainMenu,"Maipull_MainMenuOpt");
      Maipull_MainMenuOpt->initialize();
  Maipull_MainMenuOpt->setPropertyV(WSNmenuItems,"Config URL(U):MainMenuCnfUrl:U:1,Config(C):MainMenuCnfMisc:C:2");
  Maipull_MainMenuOpt->setPropertyV(WSNshortcut,"O");
  Maipull_MainMenuOpt->setPropertyV(WSNusePixmap,(WSCbool)1);
  Maipull_MainMenuOpt->setPropertyV(WSNlabelString,"Option(O)");
  Maipull_MainMenuOpt->setPropertyV(WSNname,"Maipull_MainMenuOpt");
  Maipull_MainMenuOpt->setPropertyV(WSNvis,(WSCbool)1);
  Maipull_MainMenuOpt->setPropertyV(WSNx,(short)100);
  Maipull_MainMenuOpt->setPropertyV(WSNheight,(unsigned short)28);
    WSCprocedure* op_Maipull_MainMenuOpt_5 = new WSCprocedure("MainMenuCnfUrl",-1);
    extern void MainMenuCnfUrl(WSCbase*);
    op_Maipull_MainMenuOpt_5->setFunction(MainMenuCnfUrl,"MainMenuCnfUrl");
    Maipull_MainMenuOpt->addProcedure(op_Maipull_MainMenuOpt_5);
    WSCprocedure* op_Maipull_MainMenuOpt_6 = new WSCprocedure("MainMenuCnfMisc",-1);
    extern void MainMenuCnfMisc(WSCbase*);
    op_Maipull_MainMenuOpt_6->setFunction(MainMenuCnfMisc,"MainMenuCnfMisc");
    Maipull_MainMenuOpt->addProcedure(op_Maipull_MainMenuOpt_6);

  Cnfdial_ConfigUrl = new  WSCdialog(MainWin,"Cnfdial_ConfigUrl");
      Cnfdial_ConfigUrl->initialize();
  Cnfdial_ConfigUrl->setPropertyV(WSNno,(WSCbool)0);
  Cnfdial_ConfigUrl->setPropertyV(WSNname,"Cnfdial_ConfigUrl");
  Cnfdial_ConfigUrl->setPropertyV(WSNtitleString,"Config URL");
  Cnfdial_ConfigUrl->setPropertyV(WSNx,(short)100);
  Cnfdial_ConfigUrl->setPropertyV(WSNy,(short)100);
  Cnfdial_ConfigUrl->setPropertyV(WSNwidth,(unsigned short)640);
  Cnfdial_ConfigUrl->setPropertyV(WSNheight,(unsigned short)400);
    WSCprocedure* op_Cnfdial_ConfigUrl_5 = new WSCprocedure("CnfWinInit",0);
    extern void CnfWinInit(WSCbase*);
    op_Cnfdial_ConfigUrl_5->setFunction(CnfWinInit,"CnfWinInit");
    Cnfdial_ConfigUrl->addProcedure(op_Cnfdial_ConfigUrl_5);
    WSCprocedure* op_Cnfdial_ConfigUrl_6 = new WSCprocedure("CnfWinPush",2);
    extern void CnfWinPush(WSCbase*);
    op_Cnfdial_ConfigUrl_6->setFunction(CnfWinPush,"CnfWinPush");
    Cnfdial_ConfigUrl->addProcedure(op_Cnfdial_ConfigUrl_6);

  Cnfvbtn_NewBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_NewBtn");
      Cnfvbtn_NewBtn->initialize();
  Cnfvbtn_NewBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvbtn_NewBtn->setPropertyV(WSNlabelString,"New");
  Cnfvbtn_NewBtn->setPropertyV(WSNname,"Cnfvbtn_NewBtn");
  Cnfvbtn_NewBtn->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvbtn_NewBtn->setPropertyV(WSNx,(short)520);
  Cnfvbtn_NewBtn->setPropertyV(WSNy,(short)320);
  Cnfvbtn_NewBtn->setPropertyV(WSNanchorBottom,(unsigned short)50);
  Cnfvbtn_NewBtn->setPropertyV(WSNanchorRight,(unsigned short)20);
  Cnfvbtn_NewBtn->setPropertyV(WSNanchorBottomFlag,(WSCbool)1);
  Cnfvbtn_NewBtn->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Cnfvbtn_NewBtn_5 = new WSCprocedure("CnfNewPush",2);
    extern void CnfNewPush(WSCbase*);
    op_Cnfvbtn_NewBtn_5->setFunction(CnfNewPush,"CnfNewPush");
    Cnfvbtn_NewBtn->addProcedure(op_Cnfvbtn_NewBtn_5);

  Cnfvbtn_UpdateBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_UpdateBtn");
      Cnfvbtn_UpdateBtn->initialize();
  Cnfvbtn_UpdateBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvbtn_UpdateBtn->setPropertyV(WSNlabelString,"Update");
  Cnfvbtn_UpdateBtn->setPropertyV(WSNname,"Cnfvbtn_UpdateBtn");
  Cnfvbtn_UpdateBtn->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvbtn_UpdateBtn->setPropertyV(WSNx,(short)400);
  Cnfvbtn_UpdateBtn->setPropertyV(WSNy,(short)320);
  Cnfvbtn_UpdateBtn->setPropertyV(WSNanchorBottom,(unsigned short)50);
  Cnfvbtn_UpdateBtn->setPropertyV(WSNanchorRight,(unsigned short)140);
  Cnfvbtn_UpdateBtn->setPropertyV(WSNanchorBottomFlag,(WSCbool)1);
  Cnfvbtn_UpdateBtn->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Cnfvbtn_UpdateBtn_5 = new WSCprocedure("CnfUpdatePush",2);
    extern void CnfUpdatePush(WSCbase*);
    op_Cnfvbtn_UpdateBtn_5->setFunction(CnfUpdatePush,"CnfUpdatePush");
    Cnfvbtn_UpdateBtn->addProcedure(op_Cnfvbtn_UpdateBtn_5);

  Cnfvifi_Name = new  WSCvifield(Cnfdial_ConfigUrl,"Cnfvifi_Name");
      Cnfvifi_Name->initialize();
  Cnfvifi_Name->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvifi_Name->setPropertyV(WSNname,"Cnfvifi_Name");
  Cnfvifi_Name->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvifi_Name->setPropertyV(WSNx,(short)120);
  Cnfvifi_Name->setPropertyV(WSNy,(short)60);
  Cnfvifi_Name->setPropertyV(WSNwidth,(unsigned short)500);
  Cnfvifi_Name->setPropertyV(WSNanchorTop,(unsigned short)60);
  Cnfvifi_Name->setPropertyV(WSNanchorLeft,(unsigned short)120);
  Cnfvifi_Name->setPropertyV(WSNanchorRight,(unsigned short)20);
  Cnfvifi_Name->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvifi_Name->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
  Cnfvifi_Name->setPropertyV(WSNanchorRightFlag,(WSCbool)1);

  Cnfvifi_Url = new  WSCvifield(Cnfdial_ConfigUrl,"Cnfvifi_Url");
      Cnfvifi_Url->initialize();
  Cnfvifi_Url->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvifi_Url->setPropertyV(WSNname,"Cnfvifi_Url");
  Cnfvifi_Url->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvifi_Url->setPropertyV(WSNx,(short)120);
  Cnfvifi_Url->setPropertyV(WSNy,(short)100);
  Cnfvifi_Url->setPropertyV(WSNwidth,(unsigned short)500);
  Cnfvifi_Url->setPropertyV(WSNanchorTop,(unsigned short)100);
  Cnfvifi_Url->setPropertyV(WSNanchorLeft,(unsigned short)120);
  Cnfvifi_Url->setPropertyV(WSNanchorRight,(unsigned short)20);
  Cnfvifi_Url->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvifi_Url->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
  Cnfvifi_Url->setPropertyV(WSNanchorRightFlag,(WSCbool)1);

  Cnfvlab_Name = new  WSCvlabel(Cnfdial_ConfigUrl,"Cnfvlab_Name");
      Cnfvlab_Name->initialize();
  Cnfvlab_Name->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvlab_Name->setPropertyV(WSNlabelString,"Name");
  Cnfvlab_Name->setPropertyV(WSNname,"Cnfvlab_Name");
  Cnfvlab_Name->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvlab_Name->setPropertyV(WSNx,(short)20);
  Cnfvlab_Name->setPropertyV(WSNy,(short)60);
  Cnfvlab_Name->setPropertyV(WSNanchorTop,(unsigned short)60);
  Cnfvlab_Name->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Cnfvlab_Name->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvlab_Name->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);

  Cnfvlab_Url = new  WSCvlabel(Cnfdial_ConfigUrl,"Cnfvlab_Url");
      Cnfvlab_Url->initialize();
  Cnfvlab_Url->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvlab_Url->setPropertyV(WSNlabelString,"URL");
  Cnfvlab_Url->setPropertyV(WSNname,"Cnfvlab_Url");
  Cnfvlab_Url->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvlab_Url->setPropertyV(WSNx,(short)20);
  Cnfvlab_Url->setPropertyV(WSNy,(short)100);
  Cnfvlab_Url->setPropertyV(WSNanchorTop,(unsigned short)100);
  Cnfvlab_Url->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Cnfvlab_Url->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvlab_Url->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);

  Cnfvtog_Download = new  WSCvtoggle(Cnfdial_ConfigUrl,"Cnfvtog_Download");
      Cnfvtog_Download->initialize();
  Cnfvtog_Download->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvtog_Download->setPropertyV(WSNlabelString,"Download");
  Cnfvtog_Download->setPropertyV(WSNname,"Cnfvtog_Download");
  Cnfvtog_Download->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvtog_Download->setPropertyV(WSNx,(short)20);
  Cnfvtog_Download->setPropertyV(WSNy,(short)260);
  Cnfvtog_Download->setPropertyV(WSNwidth,(unsigned short)200);
  Cnfvtog_Download->setPropertyV(WSNanchorTop,(unsigned short)260);
  Cnfvtog_Download->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Cnfvtog_Download->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvtog_Download->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);

  Cnfvbtn_DeleteBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_DeleteBtn");
      Cnfvbtn_DeleteBtn->initialize();
  Cnfvbtn_DeleteBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvbtn_DeleteBtn->setPropertyV(WSNlabelString,"Delete");
  Cnfvbtn_DeleteBtn->setPropertyV(WSNname,"Cnfvbtn_DeleteBtn");
  Cnfvbtn_DeleteBtn->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvbtn_DeleteBtn->setPropertyV(WSNx,(short)280);
  Cnfvbtn_DeleteBtn->setPropertyV(WSNy,(short)320);
  Cnfvbtn_DeleteBtn->setPropertyV(WSNanchorBottom,(unsigned short)50);
  Cnfvbtn_DeleteBtn->setPropertyV(WSNanchorRight,(unsigned short)260);
  Cnfvbtn_DeleteBtn->setPropertyV(WSNanchorBottomFlag,(WSCbool)1);
  Cnfvbtn_DeleteBtn->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Cnfvbtn_DeleteBtn_5 = new WSCprocedure("CnfDeletePush",2);
    extern void CnfDeletePush(WSCbase*);
    op_Cnfvbtn_DeleteBtn_5->setFunction(CnfDeletePush,"CnfDeletePush");
    Cnfvbtn_DeleteBtn->addProcedure(op_Cnfvbtn_DeleteBtn_5);

  Cnfcomb_NameList = new  WSCcomboBox(Cnfdial_ConfigUrl,"Cnfcomb_NameList");
      Cnfcomb_NameList->initialize();
  Cnfcomb_NameList->setPropertyV(WSNmenuItems,"");
  Cnfcomb_NameList->setPropertyV(WSNbackBlinkColor,"DEF13");
  Cnfcomb_NameList->setPropertyV(WSNworkBackColor,"DEF11");
  Cnfcomb_NameList->setPropertyV(WSNusePixmap,(unsigned char)1);
  Cnfcomb_NameList->setPropertyV(WSNalignmentH,(unsigned char)0);
  Cnfcomb_NameList->setPropertyV(WSNmaxLength,(unsigned short)512);
  Cnfcomb_NameList->setPropertyV(WSNfont,(unsigned char)1);
  Cnfcomb_NameList->setPropertyV(WSNname,"Cnfcomb_NameList");
  Cnfcomb_NameList->setPropertyV(WSNx,(short)20);
  Cnfcomb_NameList->setPropertyV(WSNy,(short)20);
  Cnfcomb_NameList->setPropertyV(WSNwidth,(unsigned short)600);
  Cnfcomb_NameList->setPropertyV(WSNvis,(WSCbool)1);
  Cnfcomb_NameList->setPropertyV(WSNanchorTop,(unsigned short)20);
  Cnfcomb_NameList->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Cnfcomb_NameList->setPropertyV(WSNanchorRight,(unsigned short)20);
  Cnfcomb_NameList->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfcomb_NameList->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
  Cnfcomb_NameList->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Cnfcomb_NameList_5 = new WSCprocedure("CnfNameListSelect",2);
    extern void CnfNameListSelect(WSCbase*);
    op_Cnfcomb_NameList_5->setFunction(CnfNameListSelect,"CnfNameListSelect");
    Cnfcomb_NameList->addProcedure(op_Cnfcomb_NameList_5);

  Cnfcomb_Encoding = new  WSCcomboBox(Cnfdial_ConfigUrl,"Cnfcomb_Encoding");
      Cnfcomb_Encoding->initialize();
  Cnfcomb_Encoding->setPropertyV(WSNmenuItems,"");
  Cnfcomb_Encoding->setPropertyV(WSNbackBlinkColor,"DEF13");
  Cnfcomb_Encoding->setPropertyV(WSNworkBackColor,"DEF11");
  Cnfcomb_Encoding->setPropertyV(WSNusePixmap,(unsigned char)1);
  Cnfcomb_Encoding->setPropertyV(WSNname,"Cnfcomb_Encoding");
  Cnfcomb_Encoding->setPropertyV(WSNx,(short)120);
  Cnfcomb_Encoding->setPropertyV(WSNy,(short)140);
  Cnfcomb_Encoding->setPropertyV(WSNwidth,(unsigned short)500);
  Cnfcomb_Encoding->setPropertyV(WSNvis,(WSCbool)1);
  Cnfcomb_Encoding->setPropertyV(WSNanchorTop,(unsigned short)140);
  Cnfcomb_Encoding->setPropertyV(WSNanchorLeft,(unsigned short)120);
  Cnfcomb_Encoding->setPropertyV(WSNanchorRight,(unsigned short)20);
  Cnfcomb_Encoding->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfcomb_Encoding->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
  Cnfcomb_Encoding->setPropertyV(WSNanchorRightFlag,(WSCbool)1);

  Cnfvlab_Encoding = new  WSCvlabel(Cnfdial_ConfigUrl,"Cnfvlab_Encoding");
      Cnfvlab_Encoding->initialize();
  Cnfvlab_Encoding->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvlab_Encoding->setPropertyV(WSNlabelString,"Encoding");
  Cnfvlab_Encoding->setPropertyV(WSNname,"Cnfvlab_Encoding");
  Cnfvlab_Encoding->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvlab_Encoding->setPropertyV(WSNx,(short)20);
  Cnfvlab_Encoding->setPropertyV(WSNy,(short)140);
  Cnfvlab_Encoding->setPropertyV(WSNanchorTop,(unsigned short)140);
  Cnfvlab_Encoding->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Cnfvlab_Encoding->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvlab_Encoding->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);

  Cnfvlab_OrderTitle = new  WSCvlabel(Cnfdial_ConfigUrl,"Cnfvlab_OrderTitle");
      Cnfvlab_OrderTitle->initialize();
  Cnfvlab_OrderTitle->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvlab_OrderTitle->setPropertyV(WSNlabelString,"Order");
  Cnfvlab_OrderTitle->setPropertyV(WSNname,"Cnfvlab_OrderTitle");
  Cnfvlab_OrderTitle->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvlab_OrderTitle->setPropertyV(WSNx,(short)20);
  Cnfvlab_OrderTitle->setPropertyV(WSNy,(short)220);
  Cnfvlab_OrderTitle->setPropertyV(WSNanchorTop,(unsigned short)220);
  Cnfvlab_OrderTitle->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Cnfvlab_OrderTitle->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvlab_OrderTitle->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);

  Cnfvlab_Order = new  WSCvlabel(Cnfdial_ConfigUrl,"Cnfvlab_Order");
      Cnfvlab_Order->initialize();
  Cnfvlab_Order->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvlab_Order->setPropertyV(WSNlabelString,"0");
  Cnfvlab_Order->setPropertyV(WSNname,"Cnfvlab_Order");
  Cnfvlab_Order->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvlab_Order->setPropertyV(WSNx,(short)120);
  Cnfvlab_Order->setPropertyV(WSNy,(short)220);
  Cnfvlab_Order->setPropertyV(WSNanchorTop,(unsigned short)220);
  Cnfvlab_Order->setPropertyV(WSNanchorLeft,(unsigned short)120);
  Cnfvlab_Order->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvlab_Order->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);

  Cnfvbtn_UpBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_UpBtn");
      Cnfvbtn_UpBtn->initialize();
  Cnfvbtn_UpBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvbtn_UpBtn->setPropertyV(WSNlabelString,"Up");
  Cnfvbtn_UpBtn->setPropertyV(WSNname,"Cnfvbtn_UpBtn");
  Cnfvbtn_UpBtn->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvbtn_UpBtn->setPropertyV(WSNx,(short)220);
  Cnfvbtn_UpBtn->setPropertyV(WSNy,(short)220);
  Cnfvbtn_UpBtn->setPropertyV(WSNanchorTop,(unsigned short)220);
  Cnfvbtn_UpBtn->setPropertyV(WSNanchorLeft,(unsigned short)220);
  Cnfvbtn_UpBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvbtn_UpBtn->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
    WSCprocedure* op_Cnfvbtn_UpBtn_5 = new WSCprocedure("CnfUpPush",2);
    extern void CnfUpPush(WSCbase*);
    op_Cnfvbtn_UpBtn_5->setFunction(CnfUpPush,"CnfUpPush");
    Cnfvbtn_UpBtn->addProcedure(op_Cnfvbtn_UpBtn_5);

  Cnfvbtn_DownBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_DownBtn");
      Cnfvbtn_DownBtn->initialize();
  Cnfvbtn_DownBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvbtn_DownBtn->setPropertyV(WSNlabelString,"Down");
  Cnfvbtn_DownBtn->setPropertyV(WSNname,"Cnfvbtn_DownBtn");
  Cnfvbtn_DownBtn->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvbtn_DownBtn->setPropertyV(WSNx,(short)320);
  Cnfvbtn_DownBtn->setPropertyV(WSNy,(short)220);
  Cnfvbtn_DownBtn->setPropertyV(WSNanchorTop,(unsigned short)220);
  Cnfvbtn_DownBtn->setPropertyV(WSNanchorLeft,(unsigned short)320);
  Cnfvbtn_DownBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvbtn_DownBtn->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
    WSCprocedure* op_Cnfvbtn_DownBtn_5 = new WSCprocedure("CnfDownPush",2);
    extern void CnfDownPush(WSCbase*);
    op_Cnfvbtn_DownBtn_5->setFunction(CnfDownPush,"CnfDownPush");
    Cnfvbtn_DownBtn->addProcedure(op_Cnfvbtn_DownBtn_5);

  Cnfvbtn_TopBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_TopBtn");
      Cnfvbtn_TopBtn->initialize();
  Cnfvbtn_TopBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvbtn_TopBtn->setPropertyV(WSNlabelString,"Top");
  Cnfvbtn_TopBtn->setPropertyV(WSNname,"Cnfvbtn_TopBtn");
  Cnfvbtn_TopBtn->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvbtn_TopBtn->setPropertyV(WSNx,(short)420);
  Cnfvbtn_TopBtn->setPropertyV(WSNy,(short)220);
  Cnfvbtn_TopBtn->setPropertyV(WSNanchorTop,(unsigned short)220);
  Cnfvbtn_TopBtn->setPropertyV(WSNanchorLeft,(unsigned short)420);
  Cnfvbtn_TopBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvbtn_TopBtn->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
    WSCprocedure* op_Cnfvbtn_TopBtn_5 = new WSCprocedure("CnfTopPush",2);
    extern void CnfTopPush(WSCbase*);
    op_Cnfvbtn_TopBtn_5->setFunction(CnfTopPush,"CnfTopPush");
    Cnfvbtn_TopBtn->addProcedure(op_Cnfvbtn_TopBtn_5);

  Cnfvbtn_BottomBtn = new  WSCvbtn(Cnfdial_ConfigUrl,"Cnfvbtn_BottomBtn");
      Cnfvbtn_BottomBtn->initialize();
  Cnfvbtn_BottomBtn->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvbtn_BottomBtn->setPropertyV(WSNlabelString,"Bottom");
  Cnfvbtn_BottomBtn->setPropertyV(WSNname,"Cnfvbtn_BottomBtn");
  Cnfvbtn_BottomBtn->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvbtn_BottomBtn->setPropertyV(WSNx,(short)520);
  Cnfvbtn_BottomBtn->setPropertyV(WSNy,(short)220);
  Cnfvbtn_BottomBtn->setPropertyV(WSNanchorTop,(unsigned short)220);
  Cnfvbtn_BottomBtn->setPropertyV(WSNanchorLeft,(unsigned short)520);
  Cnfvbtn_BottomBtn->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvbtn_BottomBtn->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
    WSCprocedure* op_Cnfvbtn_BottomBtn_5 = new WSCprocedure("CnfBottomPush",2);
    extern void CnfBottomPush(WSCbase*);
    op_Cnfvbtn_BottomBtn_5->setFunction(CnfBottomPush,"CnfBottomPush");
    Cnfvbtn_BottomBtn->addProcedure(op_Cnfvbtn_BottomBtn_5);

  Cnfvlab_SkipArt = new  WSCvlabel(Cnfdial_ConfigUrl,"Cnfvlab_SkipArt");
      Cnfvlab_SkipArt->initialize();
  Cnfvlab_SkipArt->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvlab_SkipArt->setPropertyV(WSNlabelString,"Skip Article No.");
  Cnfvlab_SkipArt->setPropertyV(WSNname,"Cnfvlab_SkipArt");
  Cnfvlab_SkipArt->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvlab_SkipArt->setPropertyV(WSNx,(short)20);
  Cnfvlab_SkipArt->setPropertyV(WSNy,(short)180);
  Cnfvlab_SkipArt->setPropertyV(WSNwidth,(unsigned short)200);
  Cnfvlab_SkipArt->setPropertyV(WSNanchorTop,(unsigned short)180);
  Cnfvlab_SkipArt->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Cnfvlab_SkipArt->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvlab_SkipArt->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);

  Cnfvsli_SkipArt = new  WSCvslider(Cnfdial_ConfigUrl,"Cnfvsli_SkipArt");
      Cnfvsli_SkipArt->initialize();
  Cnfvsli_SkipArt->setPropertyV(WSNsliderSize,(unsigned short)20);
  Cnfvsli_SkipArt->setPropertyV(WSNminimum,(short)1);
  Cnfvsli_SkipArt->setPropertyV(WSNdragInterval,(unsigned short)1);
  Cnfvsli_SkipArt->setPropertyV(WSNvalue,(short)992);
  Cnfvsli_SkipArt->setPropertyV(WSNname,"Cnfvsli_SkipArt");
  Cnfvsli_SkipArt->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvsli_SkipArt->setPropertyV(WSNx,(short)320);
  Cnfvsli_SkipArt->setPropertyV(WSNy,(short)180);
  Cnfvsli_SkipArt->setPropertyV(WSNwidth,(unsigned short)300);
  Cnfvsli_SkipArt->setPropertyV(WSNanchorTop,(unsigned short)180);
  Cnfvsli_SkipArt->setPropertyV(WSNanchorRight,(unsigned short)20);
  Cnfvsli_SkipArt->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvsli_SkipArt->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Cnfvsli_SkipArt_5 = new WSCprocedure("CnfSkipArtSliChg",3);
    extern void CnfSkipArtSliChg(WSCbase*);
    op_Cnfvsli_SkipArt_5->setFunction(CnfSkipArtSliChg,"CnfSkipArtSliChg");
    Cnfvsli_SkipArt->addProcedure(op_Cnfvsli_SkipArt_5);

  Cnfvifi_SkipArt = new  WSCvifield(Cnfdial_ConfigUrl,"Cnfvifi_SkipArt");
      Cnfvifi_SkipArt->initialize();
  Cnfvifi_SkipArt->setPropertyV(WSNusePixmap,(WSCbool)1);
  Cnfvifi_SkipArt->setPropertyV(WSNname,"Cnfvifi_SkipArt");
  Cnfvifi_SkipArt->setPropertyV(WSNvis,(WSCbool)1);
  Cnfvifi_SkipArt->setPropertyV(WSNx,(short)220);
  Cnfvifi_SkipArt->setPropertyV(WSNy,(short)180);
  Cnfvifi_SkipArt->setPropertyV(WSNanchorTop,(unsigned short)180);
  Cnfvifi_SkipArt->setPropertyV(WSNanchorLeft,(unsigned short)220);
  Cnfvifi_SkipArt->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Cnfvifi_SkipArt->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
    WSCprocedure* op_Cnfvifi_SkipArt_5 = new WSCprocedure("CnfSkipArtIfiChg",3);
    extern void CnfSkipArtIfiChg(WSCbase*);
    op_Cnfvifi_SkipArt_5->setFunction(CnfSkipArtIfiChg,"CnfSkipArtIfiChg");
    Cnfvifi_SkipArt->addProcedure(op_Cnfvifi_SkipArt_5);

  Maivtim_ReloadTimer = new  WSCvtimer(MainWin,"Maivtim_ReloadTimer");
      Maivtim_ReloadTimer->initialize();
  Maivtim_ReloadTimer->setPropertyV(WSNinterval,(unsigned long)3600000);
  Maivtim_ReloadTimer->setPropertyV(WSNrunning,(WSCbool)1);
  Maivtim_ReloadTimer->setPropertyV(WSNname,"Maivtim_ReloadTimer");
  Maivtim_ReloadTimer->setPropertyV(WSNvis,(WSCbool)1);
  Maivtim_ReloadTimer->setPropertyV(WSNx,(short)80);
  Maivtim_ReloadTimer->setPropertyV(WSNy,(short)180);
  Maivtim_ReloadTimer->setPropertyV(WSNwidth,(unsigned short)60);
    WSCprocedure* op_Maivtim_ReloadTimer_5 = new WSCprocedure("ReloadTimerUpdate",2);
    extern void ReloadTimerUpdate(WSCbase*);
    op_Maivtim_ReloadTimer_5->setFunction(ReloadTimerUpdate,"ReloadTimerUpdate");
    Maivtim_ReloadTimer->addProcedure(op_Maivtim_ReloadTimer_5);

  Misdial_ConfigMisc = new  WSCdialog(MainWin,"Misdial_ConfigMisc");
      Misdial_ConfigMisc->initialize();
  Misdial_ConfigMisc->setPropertyV(WSNno,(WSCbool)0);
  Misdial_ConfigMisc->setPropertyV(WSNname,"Misdial_ConfigMisc");
  Misdial_ConfigMisc->setPropertyV(WSNtitleString,"title1");
  Misdial_ConfigMisc->setPropertyV(WSNx,(short)100);
  Misdial_ConfigMisc->setPropertyV(WSNy,(short)100);
  Misdial_ConfigMisc->setPropertyV(WSNwidth,(unsigned short)500);
  Misdial_ConfigMisc->setPropertyV(WSNheight,(unsigned short)240);
    WSCprocedure* op_Misdial_ConfigMisc_5 = new WSCprocedure("MisWinInit",0);
    extern void MisWinInit(WSCbase*);
    op_Misdial_ConfigMisc_5->setFunction(MisWinInit,"MisWinInit");
    Misdial_ConfigMisc->addProcedure(op_Misdial_ConfigMisc_5);
    WSCprocedure* op_Misdial_ConfigMisc_6 = new WSCprocedure("MisWinPush",2);
    extern void MisWinPush(WSCbase*);
    op_Misdial_ConfigMisc_6->setFunction(MisWinPush,"MisWinPush");
    Misdial_ConfigMisc->addProcedure(op_Misdial_ConfigMisc_6);

  Misvlab_Chars = new  WSCvlabel(Misdial_ConfigMisc,"Misvlab_Chars");
      Misvlab_Chars->initialize();
  Misvlab_Chars->setPropertyV(WSNusePixmap,(WSCbool)1);
  Misvlab_Chars->setPropertyV(WSNlabelString,"Scroll characters");
  Misvlab_Chars->setPropertyV(WSNname,"Misvlab_Chars");
  Misvlab_Chars->setPropertyV(WSNvis,(WSCbool)1);
  Misvlab_Chars->setPropertyV(WSNx,(short)20);
  Misvlab_Chars->setPropertyV(WSNy,(short)20);
  Misvlab_Chars->setPropertyV(WSNwidth,(unsigned short)200);
  Misvlab_Chars->setPropertyV(WSNanchorTop,(unsigned short)20);
  Misvlab_Chars->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Misvlab_Chars->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Misvlab_Chars->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);

  Misvifi_Chars = new  WSCvifield(Misdial_ConfigMisc,"Misvifi_Chars");
      Misvifi_Chars->initialize();
  Misvifi_Chars->setPropertyV(WSNusePixmap,(WSCbool)1);
  Misvifi_Chars->setPropertyV(WSNname,"Misvifi_Chars");
  Misvifi_Chars->setPropertyV(WSNvis,(WSCbool)1);
  Misvifi_Chars->setPropertyV(WSNx,(short)220);
  Misvifi_Chars->setPropertyV(WSNy,(short)20);
  Misvifi_Chars->setPropertyV(WSNanchorTop,(unsigned short)20);
  Misvifi_Chars->setPropertyV(WSNanchorLeft,(unsigned short)220);
  Misvifi_Chars->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Misvifi_Chars->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
    WSCprocedure* op_Misvifi_Chars_5 = new WSCprocedure("MisCharsIfiChg",3);
    extern void MisCharsIfiChg(WSCbase*);
    op_Misvifi_Chars_5->setFunction(MisCharsIfiChg,"MisCharsIfiChg");
    Misvifi_Chars->addProcedure(op_Misvifi_Chars_5);

  Misvsli_Chars = new  WSCvslider(Misdial_ConfigMisc,"Misvsli_Chars");
      Misvsli_Chars->initialize();
  Misvsli_Chars->setPropertyV(WSNsliderSize,(unsigned short)20);
  Misvsli_Chars->setPropertyV(WSNmaximum,(short)100);
  Misvsli_Chars->setPropertyV(WSNminimum,(short)1);
  Misvsli_Chars->setPropertyV(WSNdragInterval,(unsigned short)1);
  Misvsli_Chars->setPropertyV(WSNvalue,(short)12);
  Misvsli_Chars->setPropertyV(WSNname,"Misvsli_Chars");
  Misvsli_Chars->setPropertyV(WSNvis,(WSCbool)1);
  Misvsli_Chars->setPropertyV(WSNx,(short)320);
  Misvsli_Chars->setPropertyV(WSNy,(short)20);
  Misvsli_Chars->setPropertyV(WSNwidth,(unsigned short)160);
  Misvsli_Chars->setPropertyV(WSNanchorTop,(unsigned short)20);
  Misvsli_Chars->setPropertyV(WSNanchorLeft,(unsigned short)320);
  Misvsli_Chars->setPropertyV(WSNanchorRight,(unsigned short)20);
  Misvsli_Chars->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Misvsli_Chars->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
  Misvsli_Chars->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Misvsli_Chars_5 = new WSCprocedure("MisCharsSliChg",3);
    extern void MisCharsSliChg(WSCbase*);
    op_Misvsli_Chars_5->setFunction(MisCharsSliChg,"MisCharsSliChg");
    Misvsli_Chars->addProcedure(op_Misvsli_Chars_5);

  Misvlab_Speed = new  WSCvlabel(Misdial_ConfigMisc,"Misvlab_Speed");
      Misvlab_Speed->initialize();
  Misvlab_Speed->setPropertyV(WSNusePixmap,(WSCbool)1);
  Misvlab_Speed->setPropertyV(WSNlabelString,"Scroll speed");
  Misvlab_Speed->setPropertyV(WSNname,"Misvlab_Speed");
  Misvlab_Speed->setPropertyV(WSNvis,(WSCbool)1);
  Misvlab_Speed->setPropertyV(WSNx,(short)20);
  Misvlab_Speed->setPropertyV(WSNy,(short)60);
  Misvlab_Speed->setPropertyV(WSNwidth,(unsigned short)200);
  Misvlab_Speed->setPropertyV(WSNanchorTop,(unsigned short)60);
  Misvlab_Speed->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Misvlab_Speed->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Misvlab_Speed->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);

  Misvifi_Speed = new  WSCvifield(Misdial_ConfigMisc,"Misvifi_Speed");
      Misvifi_Speed->initialize();
  Misvifi_Speed->setPropertyV(WSNusePixmap,(WSCbool)1);
  Misvifi_Speed->setPropertyV(WSNname,"Misvifi_Speed");
  Misvifi_Speed->setPropertyV(WSNvis,(WSCbool)1);
  Misvifi_Speed->setPropertyV(WSNx,(short)220);
  Misvifi_Speed->setPropertyV(WSNy,(short)60);
  Misvifi_Speed->setPropertyV(WSNanchorTop,(unsigned short)60);
  Misvifi_Speed->setPropertyV(WSNanchorLeft,(unsigned short)220);
  Misvifi_Speed->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Misvifi_Speed->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
    WSCprocedure* op_Misvifi_Speed_5 = new WSCprocedure("MisSpeedIfiChg",3);
    extern void MisSpeedIfiChg(WSCbase*);
    op_Misvifi_Speed_5->setFunction(MisSpeedIfiChg,"MisSpeedIfiChg");
    Misvifi_Speed->addProcedure(op_Misvifi_Speed_5);

  Misvsli_Speed = new  WSCvslider(Misdial_ConfigMisc,"Misvsli_Speed");
      Misvsli_Speed->initialize();
  Misvsli_Speed->setPropertyV(WSNsliderSize,(unsigned short)20);
  Misvsli_Speed->setPropertyV(WSNminimum,(short)1);
  Misvsli_Speed->setPropertyV(WSNdragInterval,(unsigned short)1);
  Misvsli_Speed->setPropertyV(WSNvalue,(short)22);
  Misvsli_Speed->setPropertyV(WSNname,"Misvsli_Speed");
  Misvsli_Speed->setPropertyV(WSNvis,(WSCbool)1);
  Misvsli_Speed->setPropertyV(WSNx,(short)320);
  Misvsli_Speed->setPropertyV(WSNy,(short)60);
  Misvsli_Speed->setPropertyV(WSNwidth,(unsigned short)160);
  Misvsli_Speed->setPropertyV(WSNanchorTop,(unsigned short)60);
  Misvsli_Speed->setPropertyV(WSNanchorLeft,(unsigned short)320);
  Misvsli_Speed->setPropertyV(WSNanchorRight,(unsigned short)20);
  Misvsli_Speed->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Misvsli_Speed->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
  Misvsli_Speed->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Misvsli_Speed_5 = new WSCprocedure("MisSpeedSliChg",3);
    extern void MisSpeedSliChg(WSCbase*);
    op_Misvsli_Speed_5->setFunction(MisSpeedSliChg,"MisSpeedSliChg");
    Misvsli_Speed->addProcedure(op_Misvsli_Speed_5);

  Misvlab_Wait = new  WSCvlabel(Misdial_ConfigMisc,"Misvlab_Wait");
      Misvlab_Wait->initialize();
  Misvlab_Wait->setPropertyV(WSNusePixmap,(WSCbool)1);
  Misvlab_Wait->setPropertyV(WSNlabelString,"Wait");
  Misvlab_Wait->setPropertyV(WSNname,"Misvlab_Wait");
  Misvlab_Wait->setPropertyV(WSNvis,(WSCbool)1);
  Misvlab_Wait->setPropertyV(WSNx,(short)20);
  Misvlab_Wait->setPropertyV(WSNy,(short)100);
  Misvlab_Wait->setPropertyV(WSNwidth,(unsigned short)200);
  Misvlab_Wait->setPropertyV(WSNanchorTop,(unsigned short)100);
  Misvlab_Wait->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Misvlab_Wait->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Misvlab_Wait->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);

  Misvifi_Wait = new  WSCvifield(Misdial_ConfigMisc,"Misvifi_Wait");
      Misvifi_Wait->initialize();
  Misvifi_Wait->setPropertyV(WSNusePixmap,(WSCbool)1);
  Misvifi_Wait->setPropertyV(WSNname,"Misvifi_Wait");
  Misvifi_Wait->setPropertyV(WSNvis,(WSCbool)1);
  Misvifi_Wait->setPropertyV(WSNx,(short)220);
  Misvifi_Wait->setPropertyV(WSNy,(short)100);
  Misvifi_Wait->setPropertyV(WSNanchorTop,(unsigned short)100);
  Misvifi_Wait->setPropertyV(WSNanchorLeft,(unsigned short)220);
  Misvifi_Wait->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Misvifi_Wait->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
    WSCprocedure* op_Misvifi_Wait_5 = new WSCprocedure("MisWaitIfiChg",3);
    extern void MisWaitIfiChg(WSCbase*);
    op_Misvifi_Wait_5->setFunction(MisWaitIfiChg,"MisWaitIfiChg");
    Misvifi_Wait->addProcedure(op_Misvifi_Wait_5);

  Misvsli_Wait = new  WSCvslider(Misdial_ConfigMisc,"Misvsli_Wait");
      Misvsli_Wait->initialize();
  Misvsli_Wait->setPropertyV(WSNsliderSize,(unsigned short)20);
  Misvsli_Wait->setPropertyV(WSNminimum,(short)1);
  Misvsli_Wait->setPropertyV(WSNdragInterval,(unsigned short)1);
  Misvsli_Wait->setPropertyV(WSNvalue,(short)26);
  Misvsli_Wait->setPropertyV(WSNname,"Misvsli_Wait");
  Misvsli_Wait->setPropertyV(WSNvis,(WSCbool)1);
  Misvsli_Wait->setPropertyV(WSNx,(short)320);
  Misvsli_Wait->setPropertyV(WSNy,(short)100);
  Misvsli_Wait->setPropertyV(WSNwidth,(unsigned short)160);
  Misvsli_Wait->setPropertyV(WSNanchorTop,(unsigned short)100);
  Misvsli_Wait->setPropertyV(WSNanchorLeft,(unsigned short)320);
  Misvsli_Wait->setPropertyV(WSNanchorRight,(unsigned short)20);
  Misvsli_Wait->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Misvsli_Wait->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
  Misvsli_Wait->setPropertyV(WSNanchorRightFlag,(WSCbool)1);
    WSCprocedure* op_Misvsli_Wait_5 = new WSCprocedure("MisWaitSliChg",3);
    extern void MisWaitSliChg(WSCbase*);
    op_Misvsli_Wait_5->setFunction(MisWaitSliChg,"MisWaitSliChg");
    Misvsli_Wait->addProcedure(op_Misvsli_Wait_5);

  Miscomb_Language = new  WSCcomboBox(Misdial_ConfigMisc,"Miscomb_Language");
      Miscomb_Language->initialize();
  Miscomb_Language->setPropertyV(WSNbackBlinkColor,"DEF13");
  Miscomb_Language->setPropertyV(WSNworkBackColor,"DEF11");
  Miscomb_Language->setPropertyV(WSNname,"Miscomb_Language");
  Miscomb_Language->setPropertyV(WSNx,(short)220);
  Miscomb_Language->setPropertyV(WSNy,(short)140);
  Miscomb_Language->setPropertyV(WSNwidth,(unsigned short)260);
  Miscomb_Language->setPropertyV(WSNvis,(WSCbool)1);
  Miscomb_Language->setPropertyV(WSNanchorTop,(unsigned short)140);
  Miscomb_Language->setPropertyV(WSNanchorLeft,(unsigned short)220);
  Miscomb_Language->setPropertyV(WSNanchorRight,(unsigned short)20);
  Miscomb_Language->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Miscomb_Language->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);
  Miscomb_Language->setPropertyV(WSNanchorRightFlag,(WSCbool)1);

  Misvlab_Language = new  WSCvlabel(Misdial_ConfigMisc,"Misvlab_Language");
      Misvlab_Language->initialize();
  Misvlab_Language->setPropertyV(WSNusePixmap,(WSCbool)1);
  Misvlab_Language->setPropertyV(WSNlabelString,"Language");
  Misvlab_Language->setPropertyV(WSNname,"Misvlab_Language");
  Misvlab_Language->setPropertyV(WSNvis,(WSCbool)1);
  Misvlab_Language->setPropertyV(WSNx,(short)20);
  Misvlab_Language->setPropertyV(WSNy,(short)140);
  Misvlab_Language->setPropertyV(WSNwidth,(unsigned short)200);
  Misvlab_Language->setPropertyV(WSNanchorTop,(unsigned short)140);
  Misvlab_Language->setPropertyV(WSNanchorLeft,(unsigned short)20);
  Misvlab_Language->setPropertyV(WSNanchorTopFlag,(WSCbool)1);
  Misvlab_Language->setPropertyV(WSNanchorLeftFlag,(WSCbool)1);

   MainWin->setVisible(True);
   return MainWin;
}

//--- end of src ---//
